@@ -14,8 +14,7 @@ def main():
     parser.add_argument("--name", required=True, type=str)
     app_name = parser.parse_args().name
     base_dir = create_dir(os.getcwd(), app_name)
-    # yaml_path = os.path.dirname(sys.argv[0])
-    yaml_path = __file__.replace("main.py", "")
+    yaml_path = os.path.dirname(os.path.abspath(__file__))
     with open(yaml_path + "file_contents.yml", "r") as f:
         yaml_data = yaml.safe_load(f)
         for key in yaml_data.keys():
